(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     25541,        590]
NotebookOptionsPosition[     25970,        581]
NotebookOutlinePosition[     26435,        601]
CellTagsIndexPosition[     26392,        598]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Equilibrium of Beams\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-09-25",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\
The following module aims to distinguish the difference among three types of \
constrains, i.e. pinned joint, built in constrains (cantilever beam) and \
roller supporter. 
For roller supporter, the constrains can only apply supporting force on \
vertical support, thus for any applied force it will have a trend to move as \
well as rotation, except in one case where the beam is vertical while the \
force is acting along the beam axis.
For pinned joint, it can provide supporting force in any directions, while it \
cannot provide any moment. Thus, for any forces that is not along the beam \
axis, it will have a trend of rotation due to the moment produced by the \
force. 
For cantilever beam, the wall can not only provide force in any direction, \
but also provide a moment to prevent the beam from rotating. Thus, for any \
given applied force, it will keep in equilibrium. Meanwhile, if we somehow \
take out of the moment, the constrains will degrade to pinned joint and begin \
to rotate. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`F$$ = 0, $CellContext`M$$ = 
    1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 0, $CellContext`opa3$$ =
     0, $CellContext`time1$$ = 0, $CellContext`time2$$ = 
    0, $CellContext`time3$$ = 0, $CellContext`type$$ = 
    1, $CellContext`\[Theta]d$$ = 0, $CellContext`\[Phi]d$$ = 
    0, $CellContext`\[CurlyPhi]d$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`type$$], 1, Null}, {1 -> Text[
         Style["Pinned Joint", 12]], 2 -> Text[
         Style["Cantilever Beam", 12]], 3 -> Text[
         Style["Roller Supporter", 12]]}}, {{
       Hold[$CellContext`F$$], 0, 
       Row[{
         Text[
          Style["Magitude of force", 12]], 
         Spacer[17]}]}, 0, 2}, {{
       Hold[$CellContext`\[Phi]d$$], 0, 
       Row[{
         Text[
          Style[
          "Angle of force \!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \
\[Phi](\[Degree])", 12]], 
         Spacer[0]}]}, 0, 360}, {{
       Hold[$CellContext`\[Theta]d$$], 0, 
       Row[{
         Text[
          Style[
          "Angle of bar\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \
\[Theta](\[Degree])", 12]], 
         Spacer[14]}]}, 0, 360}, {{
       Hold[$CellContext`\[CurlyPhi]d$$], 0, 
       Row[{
         Text[
          Style[
          "Angle of bar\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \
\[Theta](\[Degree])", 12]], 
         Spacer[14]}]}, 0, 360}, {{
       Hold[$CellContext`opa1$$], 0, 
       Row[{
         Text[
          Style["Reactive force", 12]], 
         Spacer[26]}]}, {1 -> Text[
         Style["On", 12]], 0 -> Text[
         Style["Off", 12]]}}, {{
       Hold[$CellContext`opa2$$], 0, 
       Row[{
         Text[
          Style["Reactive force", 12]], 
         Spacer[26]}]}, {1 -> Text[
         Style["On", 12]], 0 -> Text[
         Style["Off", 12]]}}, {{
       Hold[$CellContext`M$$], 1, 
       Row[{
         Text[
          Style["Moment", 12]]}]}, {1 -> Text[
         Style["On", 12]], 0 -> Text[
         Style["Off", 12]]}}, {{
       Hold[$CellContext`opa3$$], 0, 
       Row[{
         Text[
          Style["Reactive force", 12]], 
         Spacer[26]}]}, {1 -> Text[
         Style["On", 12]], 0 -> Text[
         Style["Off", 12]]}}, {{
       Hold[$CellContext`time1$$], 0, 
       Row[{
         Text[
          Style["Show Movement", 12]], 
         Spacer[18]}]}, 0, 1}, {{
       Hold[$CellContext`time2$$], 0, 
       Row[{
         Text[
          Style["Show Movement", 12]], 
         Spacer[18]}]}, 0, 1}, {{
       Hold[$CellContext`time3$$], 0, 
       Row[{
         Text[
          Style["Show Movement", 12]], 
         Spacer[18]}]}, 0, 1}, {
      Hold[
       Grid[{{
          Row[{
            Manipulate`Place[1]}]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[4]}, Left, Spacings -> {Automatic, 1.5}], 3 -> 
            Column[{
               Manipulate`Place[5]}, Left, Spacings -> {Automatic, 1.5}]}, 
           Dynamic[$CellContext`type$$]]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[6]}, Left, Spacings -> {Automatic, 1.5}], 2 -> 
            Column[{
               Row[{
                 Manipulate`Place[7], 
                 PaneSelector[{1 -> Row[{
                    Spacer[10], 
                    Manipulate`Place[8]}]}, 
                  Dynamic[
                   Boole[
                    
                    And[$CellContext`type$$ == 2, $CellContext`opa2$$ == 
                    1]]]]}]}, Left, Spacings -> {Automatic, 1.5}], 3 -> 
            Column[{
               Manipulate`Place[9]}, Left, Spacings -> {Automatic, 1.5}]}, 
           Dynamic[$CellContext`type$$]]}, {
          
          PaneSelector[{
           1 -> Manipulate`Place[10], 2 -> Manipulate`Place[11], 3 -> 
            Manipulate`Place[12]}, 
           Dynamic[$CellContext`type$$]]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {420., {208., 216.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`type$148341$$ = False, $CellContext`F$148342$$ = 
    0, $CellContext`\[Phi]d$148343$$ = 0, $CellContext`\[Theta]d$148344$$ = 
    0, $CellContext`\[CurlyPhi]d$148345$$ = 0, $CellContext`opa1$148346$$ = 
    False, $CellContext`opa2$148347$$ = False, $CellContext`M$148348$$ = 
    False, $CellContext`opa3$148349$$ = False, $CellContext`time1$148350$$ = 
    0, $CellContext`time2$148351$$ = 0, $CellContext`time3$148352$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`F$$ = 0, $CellContext`M$$ = 
        1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 
        0, $CellContext`opa3$$ = 0, $CellContext`time1$$ = 
        0, $CellContext`time2$$ = 0, $CellContext`time3$$ = 
        0, $CellContext`type$$ = 1, $CellContext`\[Theta]d$$ = 
        0, $CellContext`\[Phi]d$$ = 0, $CellContext`\[CurlyPhi]d$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`type$$, $CellContext`type$148341$$, False], 
        Hold[$CellContext`F$$, $CellContext`F$148342$$, 0], 
        Hold[$CellContext`\[Phi]d$$, $CellContext`\[Phi]d$148343$$, 0], 
        Hold[$CellContext`\[Theta]d$$, $CellContext`\[Theta]d$148344$$, 0], 
        Hold[$CellContext`\[CurlyPhi]d$$, $CellContext`\[CurlyPhi]d$148345$$, 
         0], 
        Hold[$CellContext`opa1$$, $CellContext`opa1$148346$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$148347$$, False], 
        Hold[$CellContext`M$$, $CellContext`M$148348$$, False], 
        Hold[$CellContext`opa3$$, $CellContext`opa3$148349$$, False], 
        Hold[$CellContext`time1$$, $CellContext`time1$148350$$, 0], 
        Hold[$CellContext`time2$$, $CellContext`time2$148351$$, 0], 
        Hold[$CellContext`time3$$, $CellContext`time3$148352$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dwf10$, $CellContext`dwf11$, $CellContext`dwf12$, \
$CellContext`dwf13$, $CellContext`dwf14$, $CellContext`dwf15$, \
$CellContext`dwf16$, $CellContext`dw1$, $CellContext`dw2$, $CellContext`dw3$, \
$CellContext`lbar$, $CellContext`rbar$, $CellContext`\[Theta]$, $CellContext`\
\[Phi]$, $CellContext`\[Gamma]$, $CellContext`\[Beta]$, $CellContext`\
\[CurlyPhi]$, $CellContext`m$, $CellContext`mom$, $CellContext`mov$, \
$CellContext`ts$, $CellContext`te$}, $CellContext`\[Theta]$ = ($CellContext`\
\[Theta]d$$/180) Pi; $CellContext`\[Phi]$ = ($CellContext`\[Phi]d$$/180) 
          Pi; $CellContext`\[CurlyPhi]$ = ($CellContext`\[CurlyPhi]d$$/180) 
          Pi; $CellContext`lbar$ = 3; $CellContext`W = 
         0.4; $CellContext`rbar$ = 
         0.15; $CellContext`m$ = $CellContext`lbar$; $CellContext`ts$ = 
         0; $CellContext`te$ = 
         1; $CellContext`mom$ = ((-$CellContext`F$$) $CellContext`lbar$) 
          Sin[$CellContext`\[Phi]$]; $CellContext`\[Gamma]$ = 
         NDSolveValue[{(((1/3) $CellContext`m$) $CellContext`lbar$^2) D[
               $CellContext`\[Alpha][$CellContext`t], {$CellContext`t, 
                2}] == $CellContext`mom$, $CellContext`\[Alpha][0] == 0, 
            Derivative[1][$CellContext`\[Alpha]][0] == 
            0}, $CellContext`\[Alpha], {$CellContext`t, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`\[Beta]$ = If[$CellContext`M$$ == 1, 
           NDSolveValue[{(((1/3) $CellContext`m$) $CellContext`lbar$^2) D[
                $CellContext`\[Alpha][$CellContext`t], {$CellContext`t, 2}] == 
             0, $CellContext`\[Alpha][0] == 0, 
             Derivative[1][$CellContext`\[Alpha]][0] == 
             0}, $CellContext`\[Alpha], {$CellContext`t, $CellContext`ts$, \
$CellContext`te$}], 
           NDSolveValue[{(((1/3) $CellContext`m$) $CellContext`lbar$^2) D[
                $CellContext`\[Alpha][$CellContext`t], {$CellContext`t, 
                 2}] == $CellContext`mom$, $CellContext`\[Alpha][0] == 0, 
             Derivative[1][$CellContext`\[Alpha]][0] == 
             0}, $CellContext`\[Alpha], {$CellContext`t, $CellContext`ts$, \
$CellContext`te$}]]; $CellContext`mov$ = NDSolveValue[{$CellContext`m$ D[
               $CellContext`move[$CellContext`t], {$CellContext`t, 
                2}] == (-$CellContext`F$$) 
             Cos[$CellContext`\[CurlyPhi]$ + $CellContext`\[Phi]$ + \
$CellContext`\[Gamma]$[$CellContext`t]], $CellContext`move[0] == 0, 
            Derivative[1][$CellContext`move][0] == 
            0}, $CellContext`move, {$CellContext`t, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`dwf1$ = {
           Opacity[
            Boole[$CellContext`opa1$$ == 0]], 
           Thickness[0.005], 
           Darker[Green], 
           
           Triangle[{{0, 0}, {(-0.4) Sin[Pi/6], (-0.4) Cos[Pi/6]}, {
             0.4 Sin[Pi/6], (-0.4) Cos[Pi/6]}}], 
           Thickness[0.012], 
           Disk[{0, 0}, 0.1], 
           Thickness[0.005], 
           
           Line[{{(-0.4) Sin[Pi/6] - 0.1, (-0.4) Cos[Pi/6]}, {
             0.4 Sin[Pi/6] + 0.1, (-0.4) Cos[Pi/6]}}], 
           Line[
            
            Table[{{(-0.4) Sin[Pi/6] + $CellContext`k - 0.1, (-0.4) 
               Cos[Pi/6]}, {(-0.4) Sin[Pi/6] - 0.1 Cos[Pi/3] + $CellContext`k - 
               0.1, (-0.4) Cos[Pi/6] - 0.1 Sin[Pi/3]}}, {$CellContext`k, 0, 
              0.6, 0.1}]]}; $CellContext`dwf2$ = Rotate[{
            Opacity[0.5], Blue, 
            Rotate[
             
             Rectangle[{
              0, (-0.5) $CellContext`W}, {$CellContext`lbar$, 
               0.5 $CellContext`W}], $CellContext`\[Theta]$, {0, 0}]}, 
           $CellContext`\[Gamma]$[$CellContext`t], {0, 
           0}]; $CellContext`dwf3$ = Rotate[{Black, 
            Thickness[0.0015], Dashed, 
            Line[{{0, 0}, $CellContext`lbar$ {
                Cos[$CellContext`\[Theta]$], 
                Sin[$CellContext`\[Theta]$]}}]}, 
           $CellContext`\[Gamma]$[$CellContext`t], {0, 
           0}]; $CellContext`dwf4$ = Rotate[{
            Opacity[
             Boole[$CellContext`F$$ != 0]], Red, 
            Thickness[0.01], 
            Arrow[{$CellContext`lbar$ {
                 Cos[$CellContext`\[Theta]$], 
                 Sin[$CellContext`\[Theta]$]} + $CellContext`F$$ {
                 Cos[$CellContext`\[Theta]$ + $CellContext`\[Phi]$], 
                 
                 Sin[$CellContext`\[Theta]$ + $CellContext`\[Phi]$]}, \
$CellContext`lbar$ {
                Cos[$CellContext`\[Theta]$], 
                Sin[$CellContext`\[Theta]$]}}]}, 
           $CellContext`\[Gamma]$[$CellContext`t], {0, 
           0}]; $CellContext`dwf5$ = Rotate[{
            Opacity[
             Boole[$CellContext`opa1$$ == 1]], 
            Thickness[0.01], 
            Arrow[{(-$CellContext`F$$) {
                Cos[$CellContext`\[Theta]$ + $CellContext`\[Phi]$], 
                Sin[$CellContext`\[Theta]$ + $CellContext`\[Phi]$]}, {0, 
              0}}]}, 
           $CellContext`\[Gamma]$[$CellContext`t], {0, 0}]; $CellContext`dw1$ = 
         Graphics[{
            Evaluate[
             
             ReplaceAll[{$CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$}, {$CellContext`t -> \
$CellContext`time1$$}]], $CellContext`dwf1$}, PlotRange -> 4, ImageSize -> 
           280, Frame -> True]; $CellContext`dwf6$ = {
           Opacity[
            Boole[$CellContext`opa2$$ == 0]], 
           Thickness[0.008], 
           Line[{{0, -0.3}, {0, 0.3}}], 
           Thickness[0.005], 
           Line[
            
            Table[{{0, -0.2 + $CellContext`k}, {-0.2, -0.3 + \
$CellContext`k}}, {$CellContext`k, 0, 0.5, 0.1}]]}; $CellContext`dwf7$ = 
         Rotate[{
            Opacity[0.5], 
            Thickness[0.005], Blue, 
            
            Rectangle[{
             0, (-0.5) $CellContext`W}, {$CellContext`lbar$, 
              0.5 $CellContext`W}]}, 
           $CellContext`\[Beta]$[$CellContext`t], {0, 0}]; $CellContext`dwf8$ = 
         Rotate[{Black, 
            Thickness[0.0015], Dashed, 
            Line[{{0, 0}, $CellContext`lbar$ {1, 0}}]}, 
           $CellContext`\[Beta]$[$CellContext`t], {0, 0}]; $CellContext`dwf9$ = 
         Rotate[{
            Opacity[
             Boole[$CellContext`F$$ != 0]], Red, 
            Thickness[0.01], 
            Arrow[{$CellContext`lbar$ {1, 0} + $CellContext`F$$ {
                 Cos[$CellContext`\[Phi]$], 
                 Sin[$CellContext`\[Phi]$]}, $CellContext`lbar$ {1, 0}}]}, 
           $CellContext`\[Beta]$[$CellContext`t], {0, 
           0}]; $CellContext`dwf10$ = Rotate[{
            Opacity[
             Boole[$CellContext`opa2$$ == 1]], 
            Thickness[0.01], 
            Arrow[{(-$CellContext`F$$) {
                Cos[$CellContext`\[Phi]$], 
                Sin[$CellContext`\[Phi]$]}, {0, 0}}]}, 
           $CellContext`\[Beta]$[$CellContext`t], {0, 
           0}]; $CellContext`dwf11$ = {
           Opacity[
            Boole[
             
             And[$CellContext`opa2$$ == 1, $CellContext`mom$ != 
              0, $CellContext`M$$ == 1]]], Blue, 
           Thickness[0.007], 
           Arrowheads[0.03], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/Part[#, 5]}]]& , {{{0, 
               0}, 0.3, Pi + (($CellContext`mom$ + 10^(-6))/6) Pi, 
               Pi - (($CellContext`mom$ + 10^(-6))/6) Pi, 100}}]], 
           Text[
           "\!\(\*\nStyleBox[\"M\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {-0.6, 0}]}; $CellContext`dw2$ = 
         Graphics[{$CellContext`dwf6$, $CellContext`dwf11$, 
            Evaluate[
             
             ReplaceAll[{$CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dwf10$}, {$CellContext`t -> \
$CellContext`time2$$}]]}, PlotRange -> 4, ImageSize -> 280, Frame -> 
           True]; $CellContext`dwf12$ = Translate[{
            Opacity[
             Boole[$CellContext`opa3$$ == 0]], 
            Thickness[0.005], 
            Darker[Green], 
            
            Triangle[{{0, 0}, {(-0.4) Sin[Pi/6], (-0.4) Cos[Pi/6]}, {
              0.4 Sin[Pi/6], (-0.4) Cos[Pi/6]}}], 
            Thickness[0.012], 
            Disk[{0, 0}, 0.1], 
            Thickness[0.005], 
            
            Line[{{(-0.4) Sin[Pi/6] - 0.1, (-0.4) Cos[Pi/6]}, {
              0.4 Sin[Pi/6] + 0.1, (-0.4) Cos[Pi/6]}}], 
            Disk[{(-0.3) Sin[Pi/6] - 0.05, (-0.4) Cos[Pi/6] - 0.06}, 0.06], 
            Disk[{0.3 Sin[Pi/6] + 0.05, (-0.4) Cos[Pi/6] - 0.06}, 0.06], 
            Disk[{0, (-0.4) Cos[Pi/6] - 0.06}, 0.06]}, {
            $CellContext`mov$[$CellContext`t], 0}]; $CellContext`dwf13$ = 
         Translate[
           Rotate[{
             Opacity[0.5], 
             Thickness[0.005], Blue, 
             Rotate[{
               
               Rectangle[{
                0, (-0.5) $CellContext`W}, {$CellContext`lbar$, 
                 0.5 $CellContext`W}]}, $CellContext`\[CurlyPhi]$, {0, 0}]}, 
            $CellContext`\[Gamma]$[$CellContext`t], {0, 0}], {
            $CellContext`mov$[$CellContext`t], 0}]; $CellContext`dwf14$ = 
         Translate[
           Rotate[{Black, 
             Thickness[0.0015], Dashed, 
             Line[{{0, 0}, $CellContext`lbar$ {
                 Cos[$CellContext`\[CurlyPhi]$], 
                 Sin[$CellContext`\[CurlyPhi]$]}}]}, 
            $CellContext`\[Gamma]$[$CellContext`t], {0, 0}], {
            $CellContext`mov$[$CellContext`t], 0}]; $CellContext`dwf15$ = 
         Translate[
           Rotate[{
             Opacity[
              Boole[$CellContext`F$$ != 0]], Red, 
             Thickness[0.01], 
             Arrow[{$CellContext`lbar$ {
                  Cos[$CellContext`\[CurlyPhi]$], 
                  Sin[$CellContext`\[CurlyPhi]$]} + $CellContext`F$$ {
                  Cos[$CellContext`\[CurlyPhi]$ + $CellContext`\[Phi]$], 
                  
                  Sin[$CellContext`\[CurlyPhi]$ + $CellContext`\[Phi]$]}, \
$CellContext`lbar$ {
                 Cos[$CellContext`\[CurlyPhi]$], 
                 Sin[$CellContext`\[CurlyPhi]$]}}]}, 
            $CellContext`\[Gamma]$[$CellContext`t], {0, 0}], {
            $CellContext`mov$[$CellContext`t], 0}]; $CellContext`dwf16$ = 
         Translate[{
            Opacity[
             Boole[$CellContext`opa3$$ == 1]], 
            Thickness[0.01], 
            Arrow[{(-$CellContext`F$$) {0, 
                
                Sin[$CellContext`\[CurlyPhi]$ + $CellContext`\[Phi]$ + \
$CellContext`\[Gamma]$[$CellContext`t]]}, {0, 0}}]}, {
            $CellContext`mov$[$CellContext`t], 0}]; $CellContext`dw3$ = 
         Graphics[{
            Evaluate[
             
             ReplaceAll[{$CellContext`dwf13$, $CellContext`dwf14$, \
$CellContext`dwf12$, $CellContext`dwf15$, $CellContext`dwf16$}, \
{$CellContext`t -> $CellContext`time3$$}]]}, PlotRange -> 4, ImageSize -> 280,
            Frame -> True]; 
        Switch[$CellContext`type$$, 1, $CellContext`dw1$, 
          2, $CellContext`dw2$, 3, $CellContext`dw3$]], 
      "Specifications" :> {{{$CellContext`type$$, 1, Null}, {1 -> Text[
            Style["Pinned Joint", 12]], 2 -> Text[
            Style["Cantilever Beam", 12]], 3 -> Text[
            Style["Roller Supporter", 12]]}, ControlType -> RadioButton, 
         ControlPlacement -> 1}, {{$CellContext`F$$, 0, 
          Row[{
            Text[
             Style["Magitude of force", 12]], 
            Spacer[17]}]}, 0, 2, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 2}, {{$CellContext`\[Phi]d$$, 0, 
          Row[{
            Text[
             Style[
             "Angle of force \!\(\*\nStyleBox[\" \",\n\
FontSlant->\"Italic\"]\): \[Phi](\[Degree])", 12]], 
            Spacer[0]}]}, 0, 360, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 3}, {{$CellContext`\[Theta]d$$, 0, 
          Row[{
            Text[
             Style[
             "Angle of bar\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \
\[Theta](\[Degree])", 12]], 
            Spacer[14]}]}, 0, 360, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`\[CurlyPhi]d$$, 0, 
          Row[{
            Text[
             Style[
             "Angle of bar\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \
\[Theta](\[Degree])", 12]], 
            Spacer[14]}]}, 0, 360, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{$CellContext`opa1$$, 0, 
          Row[{
            Text[
             Style["Reactive force", 12]], 
            Spacer[26]}]}, {1 -> Text[
            Style["On", 12]], 0 -> Text[
            Style["Off", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         6}, {{$CellContext`opa2$$, 0, 
          Row[{
            Text[
             Style["Reactive force", 12]], 
            Spacer[26]}]}, {1 -> Text[
            Style["On", 12]], 0 -> Text[
            Style["Off", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         7}, {{$CellContext`M$$, 1, 
          Row[{
            Text[
             Style["Moment", 12]]}]}, {1 -> Text[
            Style["On", 12]], 0 -> Text[
            Style["Off", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         8}, {{$CellContext`opa3$$, 0, 
          Row[{
            Text[
             Style["Reactive force", 12]], 
            Spacer[26]}]}, {1 -> Text[
            Style["On", 12]], 0 -> Text[
            Style["Off", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         9}, {{$CellContext`time1$$, 0, 
          Row[{
            Text[
             Style["Show Movement", 12]], 
            Spacer[18]}]}, 0, 1, ImageSize -> Tiny, ControlType -> Trigger, 
         AppearanceElements -> {
          "PlayPauseButton", "ResetButton", "FasterSlowerButtons"}, 
         ControlPlacement -> 10}, {{$CellContext`time2$$, 0, 
          Row[{
            Text[
             Style["Show Movement", 12]], 
            Spacer[18]}]}, 0, 1, ImageSize -> Tiny, ControlType -> Trigger, 
         AppearanceElements -> {
          "PlayPauseButton", "ResetButton", "FasterSlowerButtons"}, 
         ControlPlacement -> 11}, {{$CellContext`time3$$, 0, 
          Row[{
            Text[
             Style["Show Movement", 12]], 
            Spacer[18]}]}, 0, 1, ImageSize -> Tiny, ControlType -> Trigger, 
         AppearanceElements -> {
          "PlayPauseButton", "ResetButton", "FasterSlowerButtons"}, 
         ControlPlacement -> 12}, 
        Grid[{{
           Row[{
             Manipulate`Place[1]}]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[4]}, Left, Spacings -> {Automatic, 1.5}], 3 -> 
             Column[{
                Manipulate`Place[5]}, Left, Spacings -> {Automatic, 1.5}]}, 
            Dynamic[$CellContext`type$$]]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[6]}, Left, Spacings -> {Automatic, 1.5}], 2 -> 
             Column[{
                Row[{
                  Manipulate`Place[7], 
                  PaneSelector[{1 -> Row[{
                    Spacer[10], 
                    Manipulate`Place[8]}]}, 
                   Dynamic[
                    Boole[
                    
                    And[$CellContext`type$$ == 2, $CellContext`opa2$$ == 
                    1]]]]}]}, Left, Spacings -> {Automatic, 1.5}], 3 -> 
             Column[{
                Manipulate`Place[9]}, Left, Spacings -> {Automatic, 1.5}]}, 
            Dynamic[$CellContext`type$$]]}, {
           
           PaneSelector[{
            1 -> Manipulate`Place[10], 2 -> Manipulate`Place[11], 3 -> 
             Manipulate`Place[12]}, 
            Dynamic[$CellContext`type$$]]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{978., {253., 262.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 206, 7, 230, "Title"],
Cell[1695, 44, 1025, 17, 216, "Text"],
Cell[2723, 63, 23231, 515, 539, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 5xDlokcWZlHNqBw1M@2g6swl *)
